@@ -41,6 +41,8 @@
 
 #include "brasero-media-private.h"
 
+#include "brasero-drive-priv.h"
+
 #include "scsi-device.h"
 #include "scsi-utils.h"
 #include "scsi-spc1.h"
@@ -79,14 +81,6 @@ static guint medium_monitor_signals[LAST_SIGNAL] = { 0 };
 G_DEFINE_TYPE (BraseroMediumMonitor, brasero_medium_monitor, G_TYPE_OBJECT);
 
 
-/**
- * These definitions go here as they shouldn't be public and they're used only 
- * here.
- */
-
-gboolean
-brasero_drive_probing (BraseroDrive *drive);
-
 /**
  * brasero_medium_monitor_get_drive:
  * @monitor: a #BraseroMediumMonitor
@@ -163,7 +157,7 @@ brasero_medium_monitor_is_probing (BraseroMediumMonitor *monitor)
  *
  * Gets the list of available drives that are of the given type.
  *
- * Return value: a #GSList or NULL
+ * Return value: (element-type BraseroMedia.Drive) (transfer full): a #GSList of  #BraseroDrive or NULL. The list must be freed and the element unreffed when finished.
  **/
 GSList *
 brasero_medium_monitor_get_drives (BraseroMediumMonitor *monitor,
@@ -212,7 +206,7 @@ brasero_medium_monitor_get_drives (BraseroMediumMonitor *monitor,
  *
  * Obtains the list of available media that are of the given type.
  *
- * Return value: a #GSList or NULL
+ * Return value: (element-type BraseroMedia.Medium) (transfer full): a #GSList of  #BraseroMedium or NULL. The list must be freed and the element unreffed when finished.
  **/
 GSList *
 brasero_medium_monitor_get_media (BraseroMediumMonitor *monitor,
@@ -329,7 +323,6 @@ brasero_medium_monitor_get_media (BraseroMediumMonitor *monitor,
 					g_object_ref (medium);
 					continue;
 				}
-				continue;
 			}
 		}
 
@@ -396,6 +389,37 @@ brasero_medium_monitor_is_drive (BraseroMediumMonitor *monitor,
 	return result;
 }
 
+static BraseroDrive *
+brasero_medium_monitor_drive_new (BraseroMediumMonitor *self,
+                                  const gchar *device,
+                                  GDrive *gdrive)
+{
+	BraseroMediumMonitorPrivate *priv;
+	BraseroDrive *drive;
+
+	if (!brasero_medium_monitor_is_drive (self, device))
+		return NULL;
+
+	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (self);
+	drive = g_object_new (BRASERO_TYPE_DRIVE,
+	                      "device", device,
+			      "gdrive", gdrive,
+			      NULL);
+
+	priv->drives = g_slist_prepend (priv->drives, drive);
+
+	g_signal_connect (drive,
+			  "medium-added",
+			  G_CALLBACK (brasero_medium_monitor_medium_added_cb),
+			  self);
+	g_signal_connect (drive,
+			  "medium-removed",
+			  G_CALLBACK (brasero_medium_monitor_medium_removed_cb),
+			  self);
+
+	return drive;
+}
+
 static void
 brasero_medium_monitor_device_added (BraseroMediumMonitor *self,
                                      const gchar *device,
@@ -425,28 +449,11 @@ brasero_medium_monitor_device_added (BraseroMediumMonitor *self,
 	}
 
 	/* Make sure it's an optical drive */
-	if (!brasero_medium_monitor_is_drive (self, device))
+	drive = brasero_medium_monitor_drive_new (self, device, gdrive);
+	if (!drive)
 		return;
 
 	BRASERO_MEDIA_LOG ("New drive added");
-
-	drive = g_object_new (BRASERO_TYPE_DRIVE,
-	                      "device", device,
-	                      "gdrive", gdrive,
-	                      NULL);
-	priv->drives = g_slist_prepend (priv->drives, drive);
-
-	/* connect to signals. This must come before the g_signal_emit () so we
-	 * are the first to get an update on the medium inside. */
-	g_signal_connect (drive,
-			  "medium-added",
-			  G_CALLBACK (brasero_medium_monitor_medium_added_cb),
-			  self);
-	g_signal_connect (drive,
-			  "medium-removed",
-			  G_CALLBACK (brasero_medium_monitor_medium_removed_cb),
-			  self);
-
 	g_signal_emit (self,
 		       medium_monitor_signals [DRIVE_ADDED],
 		       0,
@@ -490,6 +497,7 @@ brasero_medium_monitor_volume_added_cb (GVolumeMonitor *monitor,
 	 * associated but a GVolume. */
 	gdrive = g_volume_get_drive (gvolume);
 	if (gdrive) {
+		BRASERO_MEDIA_LOG ("Existing GDrive skipping");
 		g_object_unref (gdrive);
 		return;
 	}
@@ -585,10 +593,10 @@ brasero_medium_monitor_device_removed (BraseroMediumMonitor *self,
 			                                                  brasero_medium_monitor_disconnected_real, 
 			                                                  self);
 	}
-	else if (associated_gdrive) {
-		/* do nothing and wait for a "drive-disconnected" signal */
+	/* else do nothing and wait for a "drive-disconnected" signal */
+
+	if (associated_gdrive)
 		g_object_unref (associated_gdrive);
-	}
 
 	g_object_unref (drive);
 }
@@ -660,23 +668,7 @@ brasero_medium_monitor_init (BraseroMediumMonitor *object)
 		gdrive = iter->data;
 
 		device = g_drive_get_identifier (gdrive, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
-		if (brasero_medium_monitor_is_drive (object, device)) {
-			drive = g_object_new (BRASERO_TYPE_DRIVE,
-			                      "device", device,
-					      "gdrive", gdrive,
-					      NULL);
-
-			priv->drives = g_slist_prepend (priv->drives, drive);
-
-			g_signal_connect (drive,
-					  "medium-added",
-					  G_CALLBACK (brasero_medium_monitor_medium_added_cb),
-					  object);
-			g_signal_connect (drive,
-					  "medium-removed",
-					  G_CALLBACK (brasero_medium_monitor_medium_removed_cb),
-					  object);
-		}
+		brasero_medium_monitor_drive_new (object, device, gdrive);
 		g_free (device);
 	}
 	g_list_foreach (drives, (GFunc) g_object_unref, NULL);
@@ -702,23 +694,7 @@ brasero_medium_monitor_init (BraseroMediumMonitor *object)
 			continue;
 		}
 
-		if (brasero_medium_monitor_is_drive (object, device)) {
-			drive = g_object_new (BRASERO_TYPE_DRIVE,
-			                      "device", device,
-			                      "gdrive", NULL,
-					      NULL);
-			priv->drives = g_slist_prepend (priv->drives, drive);
-
-			g_signal_connect (drive,
-					  "medium-added",
-					  G_CALLBACK (brasero_medium_monitor_medium_added_cb),
-					  object);
-			g_signal_connect (drive,
-					  "medium-removed",
-					  G_CALLBACK (brasero_medium_monitor_medium_removed_cb),
-					  object);
-		}
-
+		brasero_medium_monitor_drive_new (object, device, NULL);
 		g_free (device);
 	}
 	g_list_foreach (volumes, (GFunc) g_object_unref, NULL);
