@@ -80,8 +80,8 @@ static ItemDescription items [] = {
 	"media-optical-data-new",
 	BRASERO_PROJECT_TYPE_DATA},
        {N_("_Video project"),
-	N_("Create a video DVD or a SVCD"),
-	N_("Create a video DVD or a SVCD that are readable on TV readers"),
+	N_("Create a video DVD or an SVCD"),
+	N_("Create a video DVD or an SVCD that is readable on TV readers"),
 	"media-optical-video-new",
 	BRASERO_PROJECT_TYPE_VIDEO},
        {N_("Disc _copy"),
@@ -297,13 +297,14 @@ brasero_project_type_chooser_build_recent (BraseroProjectTypeChooser *self,
 		gtk_button_set_alignment (GTK_BUTTON (link), 0.0, 0.5);
 		gtk_button_set_focus_on_click (GTK_BUTTON (link), FALSE);
 		gtk_button_set_image (GTK_BUTTON (link), image);
+		gtk_button_set_use_underline (GTK_BUTTON (link), TRUE);
 		g_signal_connect (link,
 				  "clicked",
 				  G_CALLBACK (brasero_project_type_chooser_last_unsaved_clicked_cb),
 				  self);
 
 		gtk_widget_show (link);
-		gtk_widget_set_tooltip_text (link, _("Load the last project that was not burnt and not saved"));
+		gtk_widget_set_tooltip_text (link, _("Load the last project that was not burned and not saved"));
 		gtk_box_pack_start (GTK_BOX (self->priv->recent_box), link, FALSE, TRUE, 0);
 
 		gtk_size_group_add_widget (group, link);
@@ -549,27 +550,26 @@ brasero_project_type_expose_event (GtkWidget *widget, GdkEventExpose *event)
 
 	chooser = BRASERO_PROJECT_TYPE_CHOOSER (widget);
 
-	if (GTK_WIDGET_DRAWABLE (widget))
+	if (gtk_widget_is_drawable (widget))
 	{
 		(* GTK_WIDGET_CLASS (parent_class)->expose_event) (widget, event);
 
-		if (!GTK_WIDGET_NO_WINDOW (widget)) {
-			if (!GTK_WIDGET_APP_PAINTABLE (widget)
+		if (gtk_widget_get_has_window (widget)) {
+			if (!gtk_widget_get_app_paintable (widget)
 			&&  chooser->priv->background) {
-				int width, offset = 150;
+				int width, height, offset = 150;
+				cairo_t *ctx;
 
 				width = gdk_pixbuf_get_width (chooser->priv->background);
-				gdk_draw_pixbuf (widget->window,
-					         widget->style->white_gc,
-						 chooser->priv->background,
-						 offset,
-						 0,
-						 0,
-						 0,
-						 width - offset,
-						 -1,
-						 GDK_RGB_DITHER_NORMAL,
-						 0, 0);
+				height = gdk_pixbuf_get_height (chooser->priv->background);
+				ctx = gdk_cairo_create (GDK_DRAWABLE (gtk_widget_get_window (widget)));
+				cairo_rectangle (ctx, 0, 0, width - offset, height);
+				cairo_clip (ctx);
+				gdk_cairo_set_source_pixbuf (ctx,
+					                     chooser->priv->background,
+					                     0, 0);
+				cairo_paint (ctx);
+				cairo_destroy (ctx);
 			}
 		}
 	}
